IBM Generative AI Python SDK
==================================

This is the Python SDK for IBM Foundation Models Studio to bring IBM Generative AI into Python programs and to also extend it with useful operations and types.

This is an early access library and requires invitation to use the technical preview of `watsonx.ai <https://watsonx.ai/>`_. You can join the waitlist by visiting https://www.ibm.com/products/watsonx-ai.


.. toctree::
   :maxdepth: 3
   :caption: APIs:

   rst_source/modules.rst
   rst_source/genai.services.rst
   rst_source/genai.schemas.rst
   rst_source/genai.prompt.rst
   rst_source/genai.exceptions.rst
   rst_source/local_server.rst

.. toctree::
   :maxdepth: 3
   :caption: Examples:

   rst_source/examples/examples.rst
   rst_source/examples/async.examples.rst
   rst_source/examples/prompts.rst
   rst_source/examples/extensions.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
